#! /usr/bin/env bash
# This file contains the complete sequence of commands
# CodeSourcery used to build this version of Sourcery G++.
# 
# For each free or open-source component of Sourcery G++, the
# source code provided includes all of the configuration
# scripts and makefiles for that component, including any and
# all modifications made by CodeSourcery.  From this list of
# commands, you can see every configuration option used by
# CodeSourcery during the build process.
# 
# This file is provided as a guideline for users who wish to
# modify and rebuild a free or open-source component of
# Sourcery G++ from source. For a number of reasons, though,
# you may not be able to successfully run this script directly
# on your system. Certain aspects of the CodeSourcery build
# environment (such as directory names) are included in these
# commands. CodeSourcery uses Canadian cross compilers so you
# may need to modify various configuration options and paths
# if you are building natively. This sequence of commands
# includes those used to build proprietary components of
# Sourcery G++ for which source code is not provided.
# 
# Please note that Sourcery G++ support covers only your use
# of the original, validated binaries provided as part of
# Sourcery G++ -- and specifically does not cover either the
# process of rebuilding a component or the use of any binaries
# you may build.  In addition, if you rebuild any component,
# you must not use the --with-pkgversion and --with-bugurl
# configuration options that embed CodeSourcery trademarks in
# the resulting binary; see the "CodeSourcery Trademarks"
# section in the Sourcery G++ Software License Agreement.
set -e
inform_fd=2 
umask 022
exec < /dev/null

error_handler ()
{
    exit 1
}

check_status() {
    local status="$?"
    if [ "$status" -ne 0 ]; then
	error_handler
    fi
}

check_pipe() {
    local -a status=("${PIPESTATUS[@]}")
    local limit=$1
    local ix
    
    if [ -z "$limit" ] ; then
	limit="${#status[@]}"
    fi
    for ((ix=0; ix != $limit ; ix++)); do
	if [ "${status[$ix]}" != "0" ] ; then
	    error_handler
	fi
    done
}

error () {
    echo "$script: error: $@" >& $inform_fd
    exit 1
}

warning () {
    echo "$script: warning: $@" >& $inform_fd
}

verbose () {
    if $gnu_verbose; then
	echo "$script: $@" >& $inform_fd
    fi
}

copy_dir() {
    mkdir -p "$2"

    (cd "$1" && tar cf - .) | (cd "$2" && tar xf -)
    check_pipe
}

copy_dir_clean() {
    mkdir -p "$2"
    (cd "$1" && tar cf - \
	--exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc \
	--exclude="*~" --exclude=".#*" \
	--exclude="*.orig" --exclude="*.rej" \
	.) | (cd "$2" && tar xf -)
    check_pipe
}

update_dir_clean() {
    mkdir -p "$2"


    (cd "$1" && tar cf - \
	--exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc \
	--exclude="*~" --exclude=".#*" \
	--exclude="*.orig" --exclude="*.rej" \
	--after-date="$3" \
	. 2> /dev/null) | (cd "$2" && tar xf -)
    check_pipe
}

copy_dir_exclude() {
    local source="$1"
    local dest="$2"
    local excl="$3"
    shift 3
    mkdir -p "$dest"
    (cd "$source" && tar cfX - "$excl" "$@") | (cd "$dest" && tar xf -)
    check_pipe
}

copy_dir_only() {
    local source="$1"
    local dest="$2"
    shift 2
    mkdir -p "$dest"
    (cd "$source" && tar cf - "$@") | (cd "$dest" && tar xf -)
    check_pipe
}

clean_environment() {
    local env_var_list
    local var




    unset BASH_ENV CDPATH POSIXLY_CORRECT TMOUT

    env_var_list=$(export | \
	grep '^declare -x ' | \
	sed -e 's/^declare -x //' -e 's/=.*//')

    for var in $env_var_list; do
	case $var in
	    HOME|HOSTNAME|LOGNAME|PWD|SHELL|SHLVL|SSH_*|TERM|USER)


		;;
	    LD_LIBRARY_PATH|PATH| \
		FLEXLM_NO_CKOUT_INSTALL_LIC|LM_APP_DISABLE_CACHE_READ)


		;;
	    MAKEINFO)

		;;
	    *_LICENSE_FILE)












		if [ "" ]; then
		    local license_file_envvar
		    license_file_envvar=

		    if [ "$var" != "$license_file_envvar" ]; then
			export -n "$var" || true
		    fi
		else
		    export -n "$var" || true
		fi
		;;
	    *)

		export -n "$var" || true
		;;
	esac
    done


    export LANG=C
    export LC_ALL=C


    export CVS_RSH=ssh



    user_shell=$SHELL
    export SHELL=$BASH
    export CONFIG_SHELL=$BASH
}

pushenv() {
    pushenv_level=$(($pushenv_level + 1))
    eval pushenv_vars_${pushenv_level}=
}


pushenv_level=0
pushenv_vars_0=



pushenvvar() {
    local pushenv_var="$1"
    local pushenv_newval="$2"
    eval local pushenv_oldval=\"\$$pushenv_var\"
    eval local pushenv_oldset=\"\${$pushenv_var+set}\"
    local pushenv_save_var=saved_${pushenv_level}_${pushenv_var}
    local pushenv_savep_var=savedp_${pushenv_level}_${pushenv_var}
    eval local pushenv_save_set=\"\${$pushenv_savep_var+set}\"
    if [ "$pushenv_save_set" = "set" ]; then
	error "Pushing $pushenv_var more than once at level $pushenv_level"
    fi
    if [ "$pushenv_oldset" = "set" ]; then
	eval $pushenv_save_var=\"\$pushenv_oldval\"
    else
	unset $pushenv_save_var
    fi
    eval $pushenv_savep_var=1
    eval export $pushenv_var=\"\$pushenv_newval\"
    local pushenv_list_var=pushenv_vars_${pushenv_level}
    eval $pushenv_list_var=\"\$$pushenv_list_var \$pushenv_var\"
}

prependenvvar() {
    local pushenv_var="$1"
    local pushenv_newval="$2"
    eval local pushenv_oldval=\"\$$pushenv_var\"
    pushenvvar "$pushenv_var" "$pushenv_newval$pushenv_oldval"
}

popenv() {
    local pushenv_var=
    eval local pushenv_vars=\"\$pushenv_vars_${pushenv_level}\"
    for pushenv_var in $pushenv_vars; do
	local pushenv_save_var=saved_${pushenv_level}_${pushenv_var}
	local pushenv_savep_var=savedp_${pushenv_level}_${pushenv_var}
	eval local pushenv_save_val=\"\$$pushenv_save_var\"
	eval local pushenv_save_set=\"\${$pushenv_save_var+set}\"
	unset $pushenv_save_var
	unset $pushenv_savep_var
	if [ "$pushenv_save_set" = "set" ]; then
	    eval export $pushenv_var=\"\$pushenv_save_val\"
	else
	    unset $pushenv_var
	fi
    done
    unset pushenv_vars_${pushenv_level}
    if [ "$pushenv_level" = "0" ]; then
	error "Popping environment level 0"
    else
	pushenv_level=$(($pushenv_level - 1))
    fi
}

prepend_path() {
    if $(eval "test -n \"\$$1\""); then
	prependenvvar "$1" "$2:"
    else
	prependenvvar "$1" "$2"
    fi
}
pushenvvar CSL_SCRIPTDIR /scratch/julian/2010q1-release-symbian-lite/src/scripts-trunk
pushenvvar PATH /usr/local/tools/gcc-4.3.3/bin
pushenvvar LD_LIBRARY_PATH /usr/local/tools/gcc-4.3.3/i686-pc-linux-gnu/lib:/usr/local/tools/gcc-4.3.3/lib64:/usr/local/tools/gcc-4.3.3/lib
pushenvvar MAKEINFO 'makeinfo --css-ref=../cs.css'
clean_environment
# task [001/130] /init/dirs
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj
mkdir -p /scratch/julian/2010q1-release-symbian-lite/install
mkdir -p /scratch/julian/2010q1-release-symbian-lite/pkg
mkdir -p /scratch/julian/2010q1-release-symbian-lite/logs/data
mkdir -p /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/html
mkdir -p /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/pdf
popenv

# task [002/130] /init/cleanup
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/pkg/arm-2010q1-190-arm-none-symbianelf.src.tar.bz2 /scratch/julian/2010q1-release-symbian-lite/pkg/arm-2010q1-190-arm-none-symbianelf.backup.tar.bz2
popenv

# task [003/130] /init/source_package/binutils
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/binutils-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/binutils-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' binutils-2010q1
popd
popenv

# task [004/130] /init/source_package/gcc
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/gcc-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/gcc-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' gcc-4.4-2010q1
popd
popenv

# task [005/130] /init/source_package/zlib
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/zlib-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/zlib-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' zlib-1.2.3
popd
popenv

# task [006/130] /init/source_package/gmp
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/gmp-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/gmp-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' gmp-2010q1
popd
popenv

# task [007/130] /init/source_package/mpfr
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/mpfr-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/mpfr-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' mpfr-2010q1
popd
popenv

# task [008/130] /init/source_package/cloog
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/cloog-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/cloog-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' cloog-0.15
popd
popenv

# task [009/130] /init/source_package/ppl
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/ppl-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/ppl-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' ppl-0.10.2
popd
popenv

# task [010/130] /init/source_package/getting_started
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/getting_started-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/getting_started-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' getting-started-2010q1
popd
popenv

# task [011/130] /init/source_package/installanywhere
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/installanywhere-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/installanywhere-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' installanywhere-2010q1
popd
popenv

# task [012/130] /init/source_package/ph
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/ph-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/ph-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' ph-2010q1
popd
popenv

# task [013/130] /init/source_package/csl_tests
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/csl_tests-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/csl_tests-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' csl-tests-trunk
popd
popenv

# task [014/130] /init/source_package/dejagnu_boards
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/dejagnu_boards-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/dejagnu_boards-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' dejagnu-boards-trunk
popd
popenv

# task [015/130] /init/source_package/scripts
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/scripts-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/scripts-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' scripts-trunk
popd
popenv

# task [016/130] /init/source_package/xfails
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/xfails-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/xfails-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' xfails-trunk
popd
popenv

# task [017/130] /init/source_package/portal
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/portal-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/portal-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' portal-trunk
popd
popenv

# task [018/130] /init/source_package/libiconv
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/libiconv-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/libiconv-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' libiconv-1.11
popd
popenv

# task [019/130] /init/source_package/csl_docbook
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/csl_docbook-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/csl_docbook-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' csl-docbook-trunk
popd
popenv

# task [020/130] /init/source_package/make
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/make-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/make-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' make-3.81
popd
popenv

# task [021/130] /init/source_package/coreutils
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/coreutils-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf/coreutils-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' coreutils-5.94
popd
popenv

# task [022/130] /init/source_package/qmtest_ph
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
rm -f /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/qmtest_ph-2010q1-190.tar.bz2
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup
pushd /scratch/julian/2010q1-release-symbian-lite/src
tar cf /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup/qmtest_ph-2010q1-190.tar.bz2 --bzip2 --owner=0 --group=0 --exclude=CVS --exclude=.svn --exclude=.git --exclude=.pc '--exclude=*~' '--exclude=.#*' '--exclude=*.orig' '--exclude=*.rej' qmtest_ph-2010q1
popd
popenv

# task [023/130] /i686-pc-linux-gnu/host_cleanup
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
popenv

# task [024/130] /i686-pc-linux-gnu/zlib_first/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/zlib-first-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
copy_dir_clean /scratch/julian/2010q1-release-symbian-lite/src/zlib-1.2.3 /scratch/julian/2010q1-release-symbian-lite/obj/zlib-first-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
chmod -R u+w /scratch/julian/2010q1-release-symbian-lite/obj/zlib-first-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
popenv

# task [025/130] /i686-pc-linux-gnu/zlib_first/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushd /scratch/julian/2010q1-release-symbian-lite/obj/zlib-first-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
pushenv
pushenvvar CC 'i686-pc-linux-gnu-gcc '
pushenvvar AR 'i686-pc-linux-gnu-ar rc'
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
./configure --prefix=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr
popenv
popd
popenv

# task [026/130] /i686-pc-linux-gnu/zlib_first/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushd /scratch/julian/2010q1-release-symbian-lite/obj/zlib-first-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv

# task [027/130] /i686-pc-linux-gnu/zlib_first/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushd /scratch/julian/2010q1-release-symbian-lite/obj/zlib-first-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make install
popd
popenv

# task [028/130] /i686-pc-linux-gnu/gmp/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushenvvar CFLAGS '-g -O2'
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/gmp-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/gmp-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/julian/2010q1-release-symbian-lite/obj/gmp-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/julian/2010q1-release-symbian-lite/src/gmp-2010q1/configure --build=i686-pc-linux-gnu --target=i686-pc-linux-gnu --prefix=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr --disable-shared --host=i686-pc-linux-gnu --enable-cxx --disable-nls
popd
popenv
popenv
popenv

# task [029/130] /i686-pc-linux-gnu/gmp/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushenvvar CFLAGS '-g -O2'
pushd /scratch/julian/2010q1-release-symbian-lite/obj/gmp-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
popenv

# task [030/130] /i686-pc-linux-gnu/gmp/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushenvvar CFLAGS '-g -O2'
pushd /scratch/julian/2010q1-release-symbian-lite/obj/gmp-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make install
popd
popenv
popenv
popenv

# task [031/130] /i686-pc-linux-gnu/gmp/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushenvvar CFLAGS '-g -O2'
pushd /scratch/julian/2010q1-release-symbian-lite/obj/gmp-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make check
popd
popenv
popenv
popenv

# task [032/130] /i686-pc-linux-gnu/mpfr/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/mpfr-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/mpfr-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/julian/2010q1-release-symbian-lite/obj/mpfr-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/julian/2010q1-release-symbian-lite/src/mpfr-2010q1/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr --disable-shared --host=i686-pc-linux-gnu --disable-nls --with-gmp=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr
popd
popenv
popenv
popenv

# task [033/130] /i686-pc-linux-gnu/mpfr/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/mpfr-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
popenv

# task [034/130] /i686-pc-linux-gnu/mpfr/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/mpfr-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make install
popd
popenv
popenv
popenv

# task [035/130] /i686-pc-linux-gnu/mpfr/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/mpfr-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make check
popd
popenv
popenv
popenv

# task [036/130] /i686-pc-linux-gnu/ppl/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/ppl-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/ppl-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/julian/2010q1-release-symbian-lite/obj/ppl-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/julian/2010q1-release-symbian-lite/src/ppl-0.10.2/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr --disable-shared --host=i686-pc-linux-gnu --disable-nls --with-libgmp-prefix=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr
popd
popenv
popenv
popenv

# task [037/130] /i686-pc-linux-gnu/ppl/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/ppl-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
popenv

# task [038/130] /i686-pc-linux-gnu/ppl/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/ppl-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make install
popd
popenv
popenv
popenv

# task [039/130] /i686-pc-linux-gnu/cloog/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/cloog-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/cloog-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/julian/2010q1-release-symbian-lite/obj/cloog-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/julian/2010q1-release-symbian-lite/src/cloog-0.15/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr --disable-shared --host=i686-pc-linux-gnu --disable-nls --with-ppl=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr --with-gmp=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr
popd
popenv
popenv
popenv

# task [040/130] /i686-pc-linux-gnu/cloog/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/cloog-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
popenv

# task [041/130] /i686-pc-linux-gnu/cloog/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/cloog-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make install
popd
popenv
popenv
popenv

# task [042/130] /i686-pc-linux-gnu/cloog/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/cloog-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make check
popd
popenv
popenv
popenv

# task [043/130] /i686-pc-linux-gnu/toolchain/binutils/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
pushenvvar LDFLAGS -L/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/binutils-src-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
copy_dir_clean /scratch/julian/2010q1-release-symbian-lite/src/binutils-2010q1 /scratch/julian/2010q1-release-symbian-lite/obj/binutils-src-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
chmod -R u+w /scratch/julian/2010q1-release-symbian-lite/obj/binutils-src-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
touch /scratch/julian/2010q1-release-symbian-lite/obj/binutils-src-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/.gnu-stamp
popenv
popenv
popenv

# task [044/130] /i686-pc-linux-gnu/toolchain/binutils/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
pushenvvar LDFLAGS -L/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/binutils-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/binutils-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/julian/2010q1-release-symbian-lite/obj/binutils-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/julian/2010q1-release-symbian-lite/obj/binutils-src-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --host=i686-pc-linux-gnu '--with-pkgversion=Sourcery G++ Lite 2010q1-190' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --enable-poison-system-directories
popd
popenv
popenv
popenv

# task [045/130] /i686-pc-linux-gnu/toolchain/binutils/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
pushenvvar LDFLAGS -L/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
pushd /scratch/julian/2010q1-release-symbian-lite/obj/binutils-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
popenv

# task [046/130] /i686-pc-linux-gnu/toolchain/binutils/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
pushenvvar LDFLAGS -L/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
pushd /scratch/julian/2010q1-release-symbian-lite/obj/binutils-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make install prefix=/scratch/julian/2010q1-release-symbian-lite/install exec_prefix=/scratch/julian/2010q1-release-symbian-lite/install libdir=/scratch/julian/2010q1-release-symbian-lite/install/lib htmldir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/html pdfdir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/pdf infodir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/info mandir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/man datadir=/scratch/julian/2010q1-release-symbian-lite/install/share
popd
popenv
popenv
popenv

# task [047/130] /i686-pc-linux-gnu/toolchain/binutils/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
pushenvvar LDFLAGS -L/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
pushd /scratch/julian/2010q1-release-symbian-lite/install
rm ./lib/libiberty.a
rmdir ./lib
popd
copy_dir_clean /scratch/julian/2010q1-release-symbian-lite/src/binutils-2010q1/include /scratch/julian/2010q1-release-symbian-lite/obj/host-binutils-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
chmod -R u+w /scratch/julian/2010q1-release-symbian-lite/obj/host-binutils-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/host-binutils-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
cp /scratch/julian/2010q1-release-symbian-lite/obj/binutils-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/libiberty/libiberty.a /scratch/julian/2010q1-release-symbian-lite/obj/host-binutils-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
cp /scratch/julian/2010q1-release-symbian-lite/obj/binutils-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/bfd/.libs/libbfd.a /scratch/julian/2010q1-release-symbian-lite/obj/host-binutils-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
cp /scratch/julian/2010q1-release-symbian-lite/obj/binutils-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/bfd/bfd.h /scratch/julian/2010q1-release-symbian-lite/obj/host-binutils-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
cp /scratch/julian/2010q1-release-symbian-lite/src/binutils-2010q1/bfd/elf-bfd.h /scratch/julian/2010q1-release-symbian-lite/obj/host-binutils-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr/include
cp /scratch/julian/2010q1-release-symbian-lite/obj/binutils-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/opcodes/.libs/libopcodes.a /scratch/julian/2010q1-release-symbian-lite/obj/host-binutils-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr/lib
rm -f /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/html/configure.html /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/pdf/etc/configure.pdf
rm -f /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/info/configure.info
install-info --infodir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/info --remove-exactly configure
rm -f /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/html/standards.html /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/pdf/etc/standards.pdf
rm -f /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/info/standards.info
install-info --infodir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/info --remove-exactly standards
rmdir /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/pdf/etc
rm -rf /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/html/bfd.html /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/pdf/bfd.pdf
rm -f /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/info/bfd.info
install-info --infodir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/info --remove-exactly bfd
rm -f /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/html/libiberty.html /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/pdf/libiberty.pdf
popenv
popenv
popenv

# task [048/130] /i686-pc-linux-gnu/toolchain/gcc_final/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/gcc-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/gcc-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/julian/2010q1-release-symbian-lite/obj/gcc-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/julian/2010q1-release-symbian-lite/src/gcc-4.4-2010q1/configure --build=i686-pc-linux-gnu --host=i686-pc-linux-gnu --target=arm-none-symbianelf --enable-threads --disable-libmudflap --disable-libssp --disable-libstdcxx-pch --enable-extra-sgxxlite-multilibs --with-gnu-as --with-gnu-ld '--with-specs=%{O2:%{!fno-remove-local-statics: -fremove-local-statics}} %{O*:%{O|O0|O1|O2|Os:;:%{!fno-remove-local-statics: -fremove-local-statics}}}' --enable-languages=c,c++ --enable-shared --disable-lto '--with-pkgversion=Sourcery G++ Lite 2010q1-190' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --prefix=/opt/codesourcery --with-gmp=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr --with-mpfr=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr --with-ppl=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr '--with-host-libstdcxx=-static-libgcc -Wl,-Bstatic,-lstdc++,-Bdynamic -lm' --with-cloog=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr --disable-libgomp --enable-poison-system-directories --with-build-time-tools=/scratch/julian/2010q1-release-symbian-lite/install/arm-none-symbianelf/bin --with-build-time-tools=/scratch/julian/2010q1-release-symbian-lite/install/arm-none-symbianelf/bin
popd
popenv
popenv

# task [049/130] /i686-pc-linux-gnu/toolchain/gcc_final/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushd /scratch/julian/2010q1-release-symbian-lite/obj/gcc-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv

# task [050/130] /i686-pc-linux-gnu/toolchain/gcc_final/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushd /scratch/julian/2010q1-release-symbian-lite/obj/gcc-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make prefix=/scratch/julian/2010q1-release-symbian-lite/install exec_prefix=/scratch/julian/2010q1-release-symbian-lite/install libdir=/scratch/julian/2010q1-release-symbian-lite/install/lib htmldir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/html pdfdir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/pdf infodir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/info mandir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/man install
popd
popenv
popenv

# task [051/130] /i686-pc-linux-gnu/toolchain/gcc_final/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushd /scratch/julian/2010q1-release-symbian-lite/install
rm bin/arm-none-symbianelf-gccbug
rm ./lib/libiberty.a
rmdir include
popd
rm -rf /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/html/gccinstall /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/pdf/gcc/gccinstall.pdf
rm -f /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/info/gccinstall.info
install-info --infodir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/info --remove-exactly gccinstall
rm -rf /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/html/gccint /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/pdf/gcc/gccint.pdf
rm -f /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/info/gccint.info
install-info --infodir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/info --remove-exactly gccint
rm -rf /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/html/cppinternals /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/pdf/gcc/cppinternals.pdf
rm -f /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/info/cppinternals.info
install-info --infodir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/info --remove-exactly cppinternals
rm -f /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/html/libiberty.html /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/pdf/libiberty.pdf
popenv
popenv

# task [052/130] /i686-pc-linux-gnu/toolchain/zlib/0/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/zlib-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
copy_dir_clean /scratch/julian/2010q1-release-symbian-lite/src/zlib-1.2.3 /scratch/julian/2010q1-release-symbian-lite/obj/zlib-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
chmod -R u+w /scratch/julian/2010q1-release-symbian-lite/obj/zlib-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
popenv

# task [053/130] /i686-pc-linux-gnu/toolchain/zlib/0/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushd /scratch/julian/2010q1-release-symbian-lite/obj/zlib-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
pushenv
pushenvvar CC 'i686-pc-linux-gnu-gcc '
pushenvvar AR 'i686-pc-linux-gnu-ar rc'
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
./configure --prefix=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/usr
popenv
popd
popenv

# task [054/130] /i686-pc-linux-gnu/toolchain/zlib/0/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushd /scratch/julian/2010q1-release-symbian-lite/obj/zlib-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv

# task [055/130] /i686-pc-linux-gnu/toolchain/zlib/0/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushd /scratch/julian/2010q1-release-symbian-lite/obj/zlib-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make install
popd
popenv

# task [056/130] /i686-pc-linux-gnu/getting_started/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/getting_started-src-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
copy_dir_clean /scratch/julian/2010q1-release-symbian-lite/src/getting-started-2010q1 /scratch/julian/2010q1-release-symbian-lite/obj/getting_started-src-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
chmod -R u+w /scratch/julian/2010q1-release-symbian-lite/obj/getting_started-src-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
touch /scratch/julian/2010q1-release-symbian-lite/obj/getting_started-src-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/.gnu-stamp
cat > /scratch/julian/2010q1-release-symbian-lite/obj/getting_started-src-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/4.4-arm-none-symbianelf-lite-libs.xml <<'EOF0'
<!DOCTYPE getting-started SYSTEM "getting-started.dtd">
<!-- automatically generated, do not edit -->
<section id="sec-multilibs">
  <title>Library Configurations</title>
  <xi:include href="library-intro.xml" xpointer="xpointer(*/*)"/>
  <section>
    <title>Included Libraries</title>
    <para>
      The following library configurations are available in
      &csl_prod; for &csl_target_name;.
    </para>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">ARMv5 - Little-Endian, Soft-Float</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry>default</entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
  <informaltable>
    <?dbfo keep-together="always" ?>
    <?dbfo table-width="100%" ?>
    <?dbhtml table-width="100%" ?>
    <tgroup cols="2" align="left">
      <colspec colname="c1" colwidth="1*" />
      <colspec colname="c2" colwidth="2*" />
      <thead>
	<row>
	  <entry namest="c1" nameend="c2">ARMv5 - Little-Endian, VFP</entry>
	</row>
      </thead>
      <tbody>
	<row>
	  <entry>Command-line option(s):</entry>
	  <entry><option>-mfloat-abi=softfp</option></entry>
	</row>
      </tbody>
    </tgroup>
  </informaltable>
    </section>
  <xi:include href="library-selection.xml"/>
</section>
EOF0
cat > /scratch/julian/2010q1-release-symbian-lite/obj/getting_started-src-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/4.4-arm-none-symbianelf-lite.dtd <<'EOF0'
<!-- automatically generated, do not edit -->
<!ENTITY csl_multilib_sec "<xi:include href='/scratch/julian/2010q1-release-symbian-lite/obj/getting_started-src-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/4.4-arm-none-symbianelf-lite-libs.xml'/>">
<!ENTITY csl_subpackage_sec "">
<!ENTITY csl_binutils_component_license "&csl_gpl3.0_license;">
<!ENTITY csl_binutils_component_version "2.19.51">
<!ENTITY csl_gcc_component_license "&csl_gpl3.0_license;">
<!ENTITY csl_gcc_component_version "4.4.1">
<!ENTITY csl_make_component_license "&csl_gpl2.0_license;">
<!ENTITY csl_coreutils_component_license "&csl_gpl2.0_license;">
EOF0
popenv
popenv
popenv

# task [057/130] /i686-pc-linux-gnu/getting_started/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/getting_started-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/getting_started-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
pushd /scratch/julian/2010q1-release-symbian-lite/obj/getting_started-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
/scratch/julian/2010q1-release-symbian-lite/obj/getting_started-src-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --host=i686-pc-linux-gnu --disable-nls --with-release-config=4.4-arm-none-symbianelf-lite '--with-components=binutils gcc zlib gmp mpfr cloog ppl getting_started installanywhere ph branding contents comparison csl_tests dejagnu_boards scripts xfails portal harness libiconv csl_docbook make coreutils qmtest_ph no-mingw no-w32api no-alf no-argp no-arm_stub no-atlas_install no-board_support no-ccs no-cctools no-cfpe_stub no-cml no-com_codesourcery_util no-compiler_wrapper no-coremark no-cs3 no-csldoc no-cxxabi no-cygwin_wrapper no-dhrystone no-dinkum no-dtc no-eclipse no-eclipse_cdt no-eclipse_plugin no-eembc no-eglibc no-eglibc_configs no-elf2flt no-elfutils no-expat no-fbench no-flexlm_utils no-gdb no-gdil no-glibc no-glibc_linuxthreads no-glibc_localedef no-glibc_ports no-harness_test no-ide no-intel_sprite no-libcsftdi no-libelf no-libfdt no-libftdi no-libkcompat no-libosip2 no-libpng no-libsdl no-libsdl_macosx no-libunwind no-liburcu no-libusb no-libusb_win32 no-license no-linux no-mips_sprite no-mips_toolchain_manual no-mklibs no-mpatrol no-mpc no-mqx no-mqx_support no-msvcrt no-ncurses no-newlib no-ocdremote no-omf2elf no-openposix no-osprey no-ph_old no-plex_skel no-prelink no-python no-python_macosx no-python_win32 no-qemu no-redboot no-rpm no-sde no-sdemdi no-sgxx_application_notes no-sgxx_demos no-simdmath no-sip_parser_benchmark no-spec2000 no-spec2000_configs no-srpm no-stellarisware no-stm32_generate_sgxx no-stm32_stdperiph_lib no-stm32_usb_fs_device_lib no-svp_docs no-sysroot_utils no-trace_processor no-uclibc no-uclibc_configs no-ust no-vpp_binary no-vpp_documentation no-vpp_fftw no-vpp_source no-windows_script_wrapper' '--with-features=armfloat tarball public elf' '--with-hosts=i686-pc-linux-gnu i686-mingw32' '--with-host_os-name=IA32 GNU/Linux' --with-target-arch-name=ARM --with-target-os-name=SymbianOS --with-intermediate-dir=/scratch/julian/2010q1-release-symbian-lite/obj/getting_started-2010q1-190-arm-none-symbianelf --with-csl-docbook=/scratch/julian/2010q1-release-symbian-lite/src/csl-docbook-trunk --with-version-string=2010q1-190 '--with-pkgversion=Sourcery G++ Lite 2010q1-190' '--with-brand=Sourcery G++ Lite' '--with-xml-catalog-files=/usr/local/tools/gcc-4.3.3/share/sgml/docbook/docbook-xsl/catalog.xml /etc/xml/catalog' --with-license=lite
popd
popenv
popenv
popenv

# task [058/130] /i686-pc-linux-gnu/getting_started/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/getting_started-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make -j4
popd
popenv
popenv
popenv

# task [059/130] /i686-pc-linux-gnu/getting_started/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/getting_started-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu
make install prefix=/scratch/julian/2010q1-release-symbian-lite/install exec_prefix=/scratch/julian/2010q1-release-symbian-lite/install libdir=/scratch/julian/2010q1-release-symbian-lite/install/lib htmldir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/html pdfdir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/pdf infodir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/info mandir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/man datadir=/scratch/julian/2010q1-release-symbian-lite/install/share docdir=/scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf
popd
popenv
popenv
popenv

# task [060/130] /i686-pc-linux-gnu/csl_docbook
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
cp /scratch/julian/2010q1-release-symbian-lite/src/csl-docbook-trunk/css/cs.css /scratch/julian/2010q1-release-symbian-lite/install/share/doc/arm-arm-none-symbianelf/html
popenv

# task [061/130] /i686-pc-linux-gnu/finalize_libc_installation
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
popenv

# task [062/130] /i686-pc-linux-gnu/pretidy_installation
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushd /scratch/julian/2010q1-release-symbian-lite/install
popd
popenv

# task [063/130] /i686-pc-linux-gnu/remove_libtool_archives
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
find /scratch/julian/2010q1-release-symbian-lite/install -name '*.la' -exec rm '{}' ';'
popenv

# task [064/130] /i686-pc-linux-gnu/remove_copied_libs
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
popenv

# task [065/130] /i686-pc-linux-gnu/remove_fixed_headers
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
pushd /scratch/julian/2010q1-release-symbian-lite/install/lib/gcc/arm-none-symbianelf/4.4.1/include-fixed
popd
popenv

# task [066/130] /i686-pc-linux-gnu/add_tooldir_readme
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
cat > /scratch/julian/2010q1-release-symbian-lite/install/arm-none-symbianelf/bin/README.txt <<'EOF0'
The executables in this directory are for internal use by the compiler
and may not operate correctly when used directly.  This directory
should not be placed on your PATH.  Instead, you should use the
executables in ../../bin/ and place that directory on your PATH.
EOF0
popenv

# task [067/130] /i686-pc-linux-gnu/strip_host_objects
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-addr2line
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-ar
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-as
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-c++
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-c++filt
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-cpp
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-g++
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-gcc
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-gcc-4.4.1
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-gcov
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-gprof
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-ld
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-nm
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-objcopy
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-objdump
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-ranlib
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-readelf
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-size
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-strings
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/bin/arm-none-symbianelf-strip
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/arm-none-symbianelf/bin/ar
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/arm-none-symbianelf/bin/as
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/arm-none-symbianelf/bin/c++
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/arm-none-symbianelf/bin/g++
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/arm-none-symbianelf/bin/gcc
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/arm-none-symbianelf/bin/ld
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/arm-none-symbianelf/bin/nm
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/arm-none-symbianelf/bin/objcopy
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/arm-none-symbianelf/bin/objdump
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/arm-none-symbianelf/bin/ranlib
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/arm-none-symbianelf/bin/strip
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/libexec/gcc/arm-none-symbianelf/4.4.1/cc1
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/libexec/gcc/arm-none-symbianelf/4.4.1/collect2
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/libexec/gcc/arm-none-symbianelf/4.4.1/install-tools/fixincl
/usr/local/tools/gcc-4.3.3/bin/i686-pc-linux-gnu-strip /scratch/julian/2010q1-release-symbian-lite/install/libexec/gcc/arm-none-symbianelf/4.4.1/cc1plus
popenv

# task [068/130] /i686-pc-linux-gnu/strip_target_objects
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
arm-none-symbianelf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/julian/2010q1-release-symbian-lite/install/arm-none-symbianelf/lib/libsupc++.a || true
arm-none-symbianelf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/julian/2010q1-release-symbian-lite/install/arm-none-symbianelf/lib/softfp/libsupc++.a || true
arm-none-symbianelf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/julian/2010q1-release-symbian-lite/install/lib/gcc/arm-none-symbianelf/4.4.1/libgcc.a || true
arm-none-symbianelf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/julian/2010q1-release-symbian-lite/install/lib/gcc/arm-none-symbianelf/4.4.1/libgcov.a || true
arm-none-symbianelf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/julian/2010q1-release-symbian-lite/install/lib/gcc/arm-none-symbianelf/4.4.1/softfp/libgcc.a || true
arm-none-symbianelf-objcopy -R .comment -R .note -R .debug_info -R .debug_aranges -R .debug_pubnames -R .debug_abbrev -R .debug_line -R .debug_str -R .debug_ranges -R .debug_loc /scratch/julian/2010q1-release-symbian-lite/install/lib/gcc/arm-none-symbianelf/4.4.1/softfp/libgcov.a || true
popenv

# task [069/130] /i686-pc-linux-gnu/package_tbz2
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
rm -f /scratch/julian/2010q1-release-symbian-lite/pkg/arm-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2
pushd /scratch/julian/2010q1-release-symbian-lite/obj
rm -f arm-2010q1
ln -s /scratch/julian/2010q1-release-symbian-lite/install arm-2010q1
tar cjf /scratch/julian/2010q1-release-symbian-lite/pkg/arm-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2 --owner=0 --group=0 --exclude=host-i686-pc-linux-gnu --exclude=host-i686-mingw32 arm-2010q1/arm-none-symbianelf arm-2010q1/bin arm-2010q1/lib arm-2010q1/libexec arm-2010q1/share
rm -f arm-2010q1
popd
popenv

# task [070/130] /i686-pc-linux-gnu/package_installanywhere
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-pc-linux-gnu-gcc
pushenvvar CXX i686-pc-linux-gnu-g++
pushenvvar AR i686-pc-linux-gnu-ar
pushenvvar RANLIB i686-pc-linux-gnu-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/install/bin
/scratch/julian/2010q1-release-symbian-lite/src/scripts-trunk/gnu-installanywhere -i /scratch/julian/2010q1-release-symbian-lite/install -l /scratch/julian/2010q1-release-symbian-lite/logs -o /scratch/julian/2010q1-release-symbian-lite/obj -p /scratch/julian/2010q1-release-symbian-lite/pkg -s /scratch/julian/2010q1-release-symbian-lite/src -T /scratch/julian/2010q1-release-symbian-lite/testlogs -h i686-pc-linux-gnu -f /scratch/julian/2010q1-release-symbian-lite/obj/getting_started-2010q1-190-arm-none-symbianelf/license.html sgxx/2010q1/arm-none-symbianelf-lite.cfg
popenv

# task [071/130] /i686-mingw32/host_cleanup
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
popenv

# task [072/130] /i686-mingw32/host_unpack
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32
mkdir /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32
pushd /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32
ln -s . arm-2010q1
tar xf /scratch/julian/2010q1-release-symbian-lite/pkg/arm-2010q1-190-arm-none-symbianelf-i686-pc-linux-gnu.tar.bz2 --bzip2
rm arm-2010q1
popd
popenv

# task [073/130] /i686-mingw32/libiconv/0/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/libiconv-2010q1-190-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/libiconv-2010q1-190-arm-none-symbianelf-i686-mingw32
pushd /scratch/julian/2010q1-release-symbian-lite/obj/libiconv-2010q1-190-arm-none-symbianelf-i686-mingw32
/scratch/julian/2010q1-release-symbian-lite/src/libiconv-1.11/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr --disable-shared --host=i686-mingw32 --disable-nls
popd
popenv
popenv
popenv

# task [074/130] /i686-mingw32/libiconv/0/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/libiconv-2010q1-190-arm-none-symbianelf-i686-mingw32
make -j1
popd
popenv
popenv
popenv

# task [075/130] /i686-mingw32/libiconv/0/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/libiconv-2010q1-190-arm-none-symbianelf-i686-mingw32
make install
popd
popenv
popenv
popenv

# task [076/130] /i686-mingw32/make/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/make-src-2010q1-190-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/julian/2010q1-release-symbian-lite/src/make-3.81 /scratch/julian/2010q1-release-symbian-lite/obj/make-src-2010q1-190-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/julian/2010q1-release-symbian-lite/obj/make-src-2010q1-190-arm-none-symbianelf-i686-mingw32
touch /scratch/julian/2010q1-release-symbian-lite/obj/make-src-2010q1-190-arm-none-symbianelf-i686-mingw32/.gnu-stamp
popenv
popenv
popenv

# task [077/130] /i686-mingw32/make/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/make-2010q1-190-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/make-2010q1-190-arm-none-symbianelf-i686-mingw32
pushd /scratch/julian/2010q1-release-symbian-lite/obj/make-2010q1-190-arm-none-symbianelf-i686-mingw32
/scratch/julian/2010q1-release-symbian-lite/obj/make-src-2010q1-190-arm-none-symbianelf-i686-mingw32/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --host=i686-mingw32 '--with-pkgversion=Sourcery G++ Lite 2010q1-190' --disable-nls --program-prefix=cs-
popd
popenv
popenv
popenv

# task [078/130] /i686-mingw32/make/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/make-2010q1-190-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
popenv

# task [079/130] /i686-mingw32/make/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/make-2010q1-190-arm-none-symbianelf-i686-mingw32
make install prefix=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32 exec_prefix=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32 libdir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/lib htmldir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/html pdfdir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf infodir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info mandir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/man datadir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share
popd
popenv
popenv
popenv

# task [080/130] /i686-mingw32/coreutils/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/coreutils-src-2010q1-190-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/julian/2010q1-release-symbian-lite/src/coreutils-5.94 /scratch/julian/2010q1-release-symbian-lite/obj/coreutils-src-2010q1-190-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/julian/2010q1-release-symbian-lite/obj/coreutils-src-2010q1-190-arm-none-symbianelf-i686-mingw32
touch /scratch/julian/2010q1-release-symbian-lite/obj/coreutils-src-2010q1-190-arm-none-symbianelf-i686-mingw32/.gnu-stamp
popenv
popenv
popenv

# task [081/130] /i686-mingw32/coreutils/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/coreutils-2010q1-190-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/coreutils-2010q1-190-arm-none-symbianelf-i686-mingw32
pushd /scratch/julian/2010q1-release-symbian-lite/obj/coreutils-2010q1-190-arm-none-symbianelf-i686-mingw32
/scratch/julian/2010q1-release-symbian-lite/obj/coreutils-src-2010q1-190-arm-none-symbianelf-i686-mingw32/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --host=i686-mingw32 '--with-pkgversion=Sourcery G++ Lite 2010q1-190' --disable-nls --program-prefix=cs-
popd
popenv
popenv
popenv

# task [082/130] /i686-mingw32/coreutils/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/coreutils-2010q1-190-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
popenv

# task [083/130] /i686-mingw32/coreutils/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/coreutils-2010q1-190-arm-none-symbianelf-i686-mingw32
make install prefix=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32 exec_prefix=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32 libdir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/lib htmldir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/html pdfdir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf infodir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info mandir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/man datadir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share
popd
popenv
popenv
popenv

# task [084/130] /i686-mingw32/zlib_first/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/zlib-first-2010q1-190-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/julian/2010q1-release-symbian-lite/src/zlib-1.2.3 /scratch/julian/2010q1-release-symbian-lite/obj/zlib-first-2010q1-190-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/julian/2010q1-release-symbian-lite/obj/zlib-first-2010q1-190-arm-none-symbianelf-i686-mingw32
popenv

# task [085/130] /i686-mingw32/zlib_first/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/julian/2010q1-release-symbian-lite/obj/zlib-first-2010q1-190-arm-none-symbianelf-i686-mingw32
pushenv
pushenvvar CC 'i686-mingw32-gcc '
pushenvvar AR 'i686-mingw32-ar rc'
pushenvvar RANLIB i686-mingw32-ranlib
./configure --prefix=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr
popenv
popd
popenv

# task [086/130] /i686-mingw32/zlib_first/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/julian/2010q1-release-symbian-lite/obj/zlib-first-2010q1-190-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv

# task [087/130] /i686-mingw32/zlib_first/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/julian/2010q1-release-symbian-lite/obj/zlib-first-2010q1-190-arm-none-symbianelf-i686-mingw32
make install
popd
popenv

# task [088/130] /i686-mingw32/gmp/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushenvvar CFLAGS '-g -O2'
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/gmp-2010q1-190-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/gmp-2010q1-190-arm-none-symbianelf-i686-mingw32
pushd /scratch/julian/2010q1-release-symbian-lite/obj/gmp-2010q1-190-arm-none-symbianelf-i686-mingw32
/scratch/julian/2010q1-release-symbian-lite/src/gmp-2010q1/configure --build=i686-pc-linux-gnu --target=i686-mingw32 --prefix=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr --disable-shared --host=i686-mingw32 --enable-cxx --disable-nls
popd
popenv
popenv
popenv

# task [089/130] /i686-mingw32/gmp/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushenvvar CFLAGS '-g -O2'
pushd /scratch/julian/2010q1-release-symbian-lite/obj/gmp-2010q1-190-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
popenv

# task [090/130] /i686-mingw32/gmp/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushenvvar CFLAGS '-g -O2'
pushd /scratch/julian/2010q1-release-symbian-lite/obj/gmp-2010q1-190-arm-none-symbianelf-i686-mingw32
make install
popd
popenv
popenv
popenv

# task [091/130] /i686-mingw32/gmp/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushenvvar CFLAGS '-g -O2'
popenv
popenv
popenv

# task [092/130] /i686-mingw32/mpfr/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/mpfr-2010q1-190-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/mpfr-2010q1-190-arm-none-symbianelf-i686-mingw32
pushd /scratch/julian/2010q1-release-symbian-lite/obj/mpfr-2010q1-190-arm-none-symbianelf-i686-mingw32
/scratch/julian/2010q1-release-symbian-lite/src/mpfr-2010q1/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr --disable-shared --host=i686-mingw32 --disable-nls --with-gmp=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr
popd
popenv
popenv
popenv

# task [093/130] /i686-mingw32/mpfr/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/mpfr-2010q1-190-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
popenv

# task [094/130] /i686-mingw32/mpfr/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/mpfr-2010q1-190-arm-none-symbianelf-i686-mingw32
make install
popd
popenv
popenv
popenv

# task [095/130] /i686-mingw32/mpfr/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
popenv
popenv
popenv

# task [096/130] /i686-mingw32/ppl/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/ppl-2010q1-190-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/ppl-2010q1-190-arm-none-symbianelf-i686-mingw32
pushd /scratch/julian/2010q1-release-symbian-lite/obj/ppl-2010q1-190-arm-none-symbianelf-i686-mingw32
/scratch/julian/2010q1-release-symbian-lite/src/ppl-0.10.2/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr --disable-shared --host=i686-mingw32 --disable-nls --with-libgmp-prefix=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr
popd
popenv
popenv
popenv

# task [097/130] /i686-mingw32/ppl/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/ppl-2010q1-190-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
popenv

# task [098/130] /i686-mingw32/ppl/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/ppl-2010q1-190-arm-none-symbianelf-i686-mingw32
make install
popd
popenv
popenv
popenv

# task [099/130] /i686-mingw32/cloog/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/cloog-2010q1-190-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/cloog-2010q1-190-arm-none-symbianelf-i686-mingw32
pushd /scratch/julian/2010q1-release-symbian-lite/obj/cloog-2010q1-190-arm-none-symbianelf-i686-mingw32
/scratch/julian/2010q1-release-symbian-lite/src/cloog-0.15/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr --disable-shared --host=i686-mingw32 --disable-nls --with-ppl=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr --with-gmp=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr
popd
popenv
popenv
popenv

# task [100/130] /i686-mingw32/cloog/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/cloog-2010q1-190-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
popenv

# task [101/130] /i686-mingw32/cloog/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushd /scratch/julian/2010q1-release-symbian-lite/obj/cloog-2010q1-190-arm-none-symbianelf-i686-mingw32
make install
popd
popenv
popenv
popenv

# task [102/130] /i686-mingw32/cloog/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
popenv
popenv
popenv

# task [103/130] /i686-mingw32/toolchain/binutils/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr/include
pushenvvar LDFLAGS -L/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr/lib
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/binutils-src-2010q1-190-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/julian/2010q1-release-symbian-lite/src/binutils-2010q1 /scratch/julian/2010q1-release-symbian-lite/obj/binutils-src-2010q1-190-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/julian/2010q1-release-symbian-lite/obj/binutils-src-2010q1-190-arm-none-symbianelf-i686-mingw32
touch /scratch/julian/2010q1-release-symbian-lite/obj/binutils-src-2010q1-190-arm-none-symbianelf-i686-mingw32/.gnu-stamp
popenv
popenv
popenv

# task [104/130] /i686-mingw32/toolchain/binutils/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr/include
pushenvvar LDFLAGS -L/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr/lib
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/binutils-2010q1-190-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/binutils-2010q1-190-arm-none-symbianelf-i686-mingw32
pushd /scratch/julian/2010q1-release-symbian-lite/obj/binutils-2010q1-190-arm-none-symbianelf-i686-mingw32
/scratch/julian/2010q1-release-symbian-lite/obj/binutils-src-2010q1-190-arm-none-symbianelf-i686-mingw32/configure --build=i686-pc-linux-gnu --target=arm-none-symbianelf --prefix=/opt/codesourcery --host=i686-mingw32 '--with-pkgversion=Sourcery G++ Lite 2010q1-190' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --enable-poison-system-directories
popd
popenv
popenv
popenv

# task [105/130] /i686-mingw32/toolchain/binutils/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr/include
pushenvvar LDFLAGS -L/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr/lib
pushd /scratch/julian/2010q1-release-symbian-lite/obj/binutils-2010q1-190-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv
popenv
popenv

# task [106/130] /i686-mingw32/toolchain/binutils/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr/include
pushenvvar LDFLAGS -L/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr/lib
pushd /scratch/julian/2010q1-release-symbian-lite/obj/binutils-2010q1-190-arm-none-symbianelf-i686-mingw32
make install prefix=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32 exec_prefix=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32 libdir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/lib htmldir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/html pdfdir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf infodir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info mandir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/man datadir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share
popd
popenv
popenv
popenv

# task [107/130] /i686-mingw32/toolchain/binutils/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenv
pushenvvar CPPFLAGS -I/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr/include
pushenvvar LDFLAGS -L/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr/lib
pushd /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32
rm lib/charset.alias
rm ./lib/libiberty.a
rmdir ./lib
popd
copy_dir_clean /scratch/julian/2010q1-release-symbian-lite/src/binutils-2010q1/include /scratch/julian/2010q1-release-symbian-lite/obj/host-binutils-2010q1-190-arm-none-symbianelf-i686-mingw32/usr/include
chmod -R u+w /scratch/julian/2010q1-release-symbian-lite/obj/host-binutils-2010q1-190-arm-none-symbianelf-i686-mingw32/usr/include
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/host-binutils-2010q1-190-arm-none-symbianelf-i686-mingw32/usr/lib
cp /scratch/julian/2010q1-release-symbian-lite/obj/binutils-2010q1-190-arm-none-symbianelf-i686-mingw32/libiberty/libiberty.a /scratch/julian/2010q1-release-symbian-lite/obj/host-binutils-2010q1-190-arm-none-symbianelf-i686-mingw32/usr/lib
cp /scratch/julian/2010q1-release-symbian-lite/obj/binutils-2010q1-190-arm-none-symbianelf-i686-mingw32/bfd/.libs/libbfd.a /scratch/julian/2010q1-release-symbian-lite/obj/host-binutils-2010q1-190-arm-none-symbianelf-i686-mingw32/usr/lib
cp /scratch/julian/2010q1-release-symbian-lite/obj/binutils-2010q1-190-arm-none-symbianelf-i686-mingw32/bfd/bfd.h /scratch/julian/2010q1-release-symbian-lite/obj/host-binutils-2010q1-190-arm-none-symbianelf-i686-mingw32/usr/include
cp /scratch/julian/2010q1-release-symbian-lite/src/binutils-2010q1/bfd/elf-bfd.h /scratch/julian/2010q1-release-symbian-lite/obj/host-binutils-2010q1-190-arm-none-symbianelf-i686-mingw32/usr/include
cp /scratch/julian/2010q1-release-symbian-lite/obj/binutils-2010q1-190-arm-none-symbianelf-i686-mingw32/opcodes/.libs/libopcodes.a /scratch/julian/2010q1-release-symbian-lite/obj/host-binutils-2010q1-190-arm-none-symbianelf-i686-mingw32/usr/lib
rm -f /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/html/configure.html /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf/etc/configure.pdf
rm -f /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info/configure.info
install-info --infodir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info --remove-exactly configure
rm -f /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/html/standards.html /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf/etc/standards.pdf
rm -f /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info/standards.info
install-info --infodir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info --remove-exactly standards
rmdir /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf/etc
rm -rf /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/html/bfd.html /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf/bfd.pdf
rm -f /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info/bfd.info
install-info --infodir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info --remove-exactly bfd
rm -f /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/html/libiberty.html /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf/libiberty.pdf
popenv
popenv
popenv

# task [108/130] /i686-mingw32/toolchain/copy_libs
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
copy_dir /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/share/doc/arm-arm-none-symbianelf/html /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/html
copy_dir /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf
copy_dir /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/share/doc/arm-arm-none-symbianelf/info /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info
copy_dir /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/share/doc/arm-arm-none-symbianelf/man /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/man
cp /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/share/doc/arm-arm-none-symbianelf/LICENSE.txt /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf
popenv

# task [109/130] /i686-mingw32/toolchain/gcc_final/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushenvvar CC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar GCC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar CXX_FOR_TARGET arm-none-symbianelf-g++
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/gcc-2010q1-190-arm-none-symbianelf-i686-mingw32
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/gcc-2010q1-190-arm-none-symbianelf-i686-mingw32
pushd /scratch/julian/2010q1-release-symbian-lite/obj/gcc-2010q1-190-arm-none-symbianelf-i686-mingw32
/scratch/julian/2010q1-release-symbian-lite/src/gcc-4.4-2010q1/configure --build=i686-pc-linux-gnu --host=i686-mingw32 --target=arm-none-symbianelf --enable-threads --disable-libmudflap --disable-libssp --disable-libstdcxx-pch --enable-extra-sgxxlite-multilibs --with-gnu-as --with-gnu-ld '--with-specs=%{O2:%{!fno-remove-local-statics: -fremove-local-statics}} %{O*:%{O|O0|O1|O2|Os:;:%{!fno-remove-local-statics: -fremove-local-statics}}}' --enable-languages=c,c++ --enable-shared --disable-lto '--with-pkgversion=Sourcery G++ Lite 2010q1-190' --with-bugurl=https://support.codesourcery.com/GNUToolchain/ --disable-nls --prefix=/opt/codesourcery --with-libiconv-prefix=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr --with-gmp=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr --with-mpfr=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr --with-ppl=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr '--with-host-libstdcxx=-static-libgcc -Wl,-Bstatic,-lstdc++,-Bdynamic -lm' --with-cloog=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr --disable-libgomp --enable-poison-system-directories --with-build-time-tools=/scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/bin --with-build-time-tools=/scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/bin
popd
popenv
popenv

# task [110/130] /i686-mingw32/toolchain/gcc_final/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushenvvar CC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar GCC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar CXX_FOR_TARGET arm-none-symbianelf-g++
pushd /scratch/julian/2010q1-release-symbian-lite/obj/gcc-2010q1-190-arm-none-symbianelf-i686-mingw32
make -j4 all-gcc
popd
popenv
popenv

# task [111/130] /i686-mingw32/toolchain/gcc_final/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushenvvar CC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar GCC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar CXX_FOR_TARGET arm-none-symbianelf-g++
pushd /scratch/julian/2010q1-release-symbian-lite/obj/gcc-2010q1-190-arm-none-symbianelf-i686-mingw32
make prefix=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32 exec_prefix=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32 libdir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/lib htmldir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/html pdfdir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf infodir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info mandir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/man install-gcc
popd
popenv
popenv

# task [112/130] /i686-mingw32/toolchain/gcc_final/postinstall
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushenv
pushenvvar AR_FOR_TARGET arm-none-symbianelf-ar
pushenvvar NM_FOR_TARGET arm-none-symbianelf-nm
pushenvvar OBJDUMP_FOR_TARET arm-none-symbianelf-objdump
pushenvvar STRIP_FOR_TARGET arm-none-symbianelf-strip
pushenvvar CC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar GCC_FOR_TARGET arm-none-symbianelf-gcc
pushenvvar CXX_FOR_TARGET arm-none-symbianelf-g++
pushd /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32
rm bin/arm-none-symbianelf-gccbug
rmdir include
popd
copy_dir /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/lib/gcc/arm-none-symbianelf /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/lib/gcc/arm-none-symbianelf
copy_dir /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/lib /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/arm-none-symbianelf/lib
copy_dir /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/arm-none-symbianelf/include/c++ /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/arm-none-symbianelf/include/c++
rm -rf /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/html/gccinstall /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf/gcc/gccinstall.pdf
rm -f /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info/gccinstall.info
install-info --infodir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info --remove-exactly gccinstall
rm -rf /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/html/gccint /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf/gcc/gccint.pdf
rm -f /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info/gccint.info
install-info --infodir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info --remove-exactly gccint
rm -rf /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/html/cppinternals /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf/gcc/cppinternals.pdf
rm -f /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info/cppinternals.info
install-info --infodir=/scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/info --remove-exactly cppinternals
rm -f /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/html/libiberty.html /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/share/doc/arm-arm-none-symbianelf/pdf/libiberty.pdf
popenv
popenv

# task [113/130] /i686-mingw32/toolchain/zlib/0/copy
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
rm -rf /scratch/julian/2010q1-release-symbian-lite/obj/zlib-2010q1-190-arm-none-symbianelf-i686-mingw32
copy_dir_clean /scratch/julian/2010q1-release-symbian-lite/src/zlib-1.2.3 /scratch/julian/2010q1-release-symbian-lite/obj/zlib-2010q1-190-arm-none-symbianelf-i686-mingw32
chmod -R u+w /scratch/julian/2010q1-release-symbian-lite/obj/zlib-2010q1-190-arm-none-symbianelf-i686-mingw32
popenv

# task [114/130] /i686-mingw32/toolchain/zlib/0/configure
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/julian/2010q1-release-symbian-lite/obj/zlib-2010q1-190-arm-none-symbianelf-i686-mingw32
pushenv
pushenvvar CC 'i686-mingw32-gcc '
pushenvvar AR 'i686-mingw32-ar rc'
pushenvvar RANLIB i686-mingw32-ranlib
./configure --prefix=/scratch/julian/2010q1-release-symbian-lite/obj/host-libs-2010q1-190-arm-none-symbianelf-i686-mingw32/usr
popenv
popd
popenv

# task [115/130] /i686-mingw32/toolchain/zlib/0/build
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/julian/2010q1-release-symbian-lite/obj/zlib-2010q1-190-arm-none-symbianelf-i686-mingw32
make -j4
popd
popenv

# task [116/130] /i686-mingw32/toolchain/zlib/0/install
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/julian/2010q1-release-symbian-lite/obj/zlib-2010q1-190-arm-none-symbianelf-i686-mingw32
make install
popd
popenv

# task [117/130] /i686-mingw32/pretidy_installation
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32
popd
popenv

# task [118/130] /i686-mingw32/remove_libtool_archives
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
find /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32 -name '*.la' -exec rm '{}' ';'
popenv

# task [119/130] /i686-mingw32/remove_copied_libs
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
popenv

# task [120/130] /i686-mingw32/remove_fixed_headers
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
pushd /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/lib/gcc/arm-none-symbianelf/4.4.1/include-fixed
popd
popenv

# task [121/130] /i686-mingw32/add_tooldir_readme
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
cat > /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/arm-none-symbianelf/bin/README.txt <<'EOF0'
The executables in this directory are for internal use by the compiler
and may not operate correctly when used directly.  This directory
should not be placed on your PATH.  Instead, you should use the
executables in ../../bin/ and place that directory on your PATH.
EOF0
popenv

# task [122/130] /i686-mingw32/strip_host_objects
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-addr2line.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-ar.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-as.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-c++.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-c++filt.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-cpp.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-g++.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-gcc-4.4.1.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-gcc.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-gcov.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-gprof.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-ld.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-nm.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-objcopy.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-objdump.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-ranlib.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-readelf.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-size.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-strings.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/arm-none-symbianelf-strip.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/cs-make.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/bin/cs-rm.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/arm-none-symbianelf/bin/ar.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/arm-none-symbianelf/bin/as.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/arm-none-symbianelf/bin/c++.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/arm-none-symbianelf/bin/g++.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/arm-none-symbianelf/bin/gcc.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/arm-none-symbianelf/bin/ld.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/arm-none-symbianelf/bin/nm.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/arm-none-symbianelf/bin/objcopy.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/arm-none-symbianelf/bin/objdump.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/arm-none-symbianelf/bin/ranlib.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/arm-none-symbianelf/bin/strip.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.4.1/cc1.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.4.1/collect2.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.4.1/install-tools/fixincl.exe
i686-mingw32-strip /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32/libexec/gcc/arm-none-symbianelf/4.4.1/cc1plus.exe
popenv

# task [123/130] /i686-mingw32/package_tbz2
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
rm -f /scratch/julian/2010q1-release-symbian-lite/pkg/arm-2010q1-190-arm-none-symbianelf-i686-mingw32.tar.bz2
pushd /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32
popd
pushd /scratch/julian/2010q1-release-symbian-lite/obj
rm -f arm-2010q1
ln -s /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32 arm-2010q1
tar cjf /scratch/julian/2010q1-release-symbian-lite/pkg/arm-2010q1-190-arm-none-symbianelf-i686-mingw32.tar.bz2 --owner=0 --group=0 --exclude=host-i686-pc-linux-gnu --exclude=host-i686-mingw32 arm-2010q1/arm-none-symbianelf arm-2010q1/bin arm-2010q1/lib arm-2010q1/libexec arm-2010q1/share
rm -f arm-2010q1
popd
popenv

# task [124/130] /i686-mingw32/package_installanywhere
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
pushenvvar CC i686-mingw32-gcc
pushenvvar CXX i686-mingw32-g++
pushenvvar AR i686-mingw32-ar
pushenvvar RANLIB i686-mingw32-ranlib
prepend_path PATH /scratch/julian/2010q1-release-symbian-lite/obj/tools-i686-pc-linux-gnu-2010q1-190-arm-none-symbianelf-i686-mingw32/bin
/scratch/julian/2010q1-release-symbian-lite/src/scripts-trunk/gnu-installanywhere -i /scratch/julian/2010q1-release-symbian-lite/install/host-i686-mingw32 -l /scratch/julian/2010q1-release-symbian-lite/logs -o /scratch/julian/2010q1-release-symbian-lite/obj -p /scratch/julian/2010q1-release-symbian-lite/pkg -s /scratch/julian/2010q1-release-symbian-lite/src -T /scratch/julian/2010q1-release-symbian-lite/testlogs -h i686-mingw32 -f /scratch/julian/2010q1-release-symbian-lite/obj/getting_started-2010q1-190-arm-none-symbianelf/license.html sgxx/2010q1/arm-none-symbianelf-lite.cfg
popenv

# task [125/130] /fini/build_summary
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
cat > /scratch/julian/2010q1-release-symbian-lite/obj/gnu-2010q1-190-arm-none-symbianelf.txt <<'EOF0'
Version Information
===================

Version:           2010q1-190
Host spec(s):      i686-pc-linux-gnu i686-mingw32
Target:            arm-none-symbianelf

Build Information
=================

Build date:             20100414
Build machine:          henry7
Build operating system: lenny/sid
Build uname:            Linux henry7 2.6.24-25-server #1 SMP Tue Oct 20 07:20:02 UTC 2009 x86_64 GNU/Linux
Build user:             julian

EOF0
popenv

# task [126/130] /fini/extras_package
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.extras
pushd /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf
tar cjf /scratch/julian/2010q1-release-symbian-lite/pkg/arm-2010q1-190-arm-none-symbianelf.extras.tar.bz2 --owner=0 --group=0 arm-2010q1-190-arm-none-symbianelf.extras
popd
popenv

# task [127/130] /fini/backups_package
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf.backup
pushd /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf
tar cjf /scratch/julian/2010q1-release-symbian-lite/pkg/arm-2010q1-190-arm-none-symbianelf.backup.tar.bz2 --owner=0 --group=0 arm-2010q1-190-arm-none-symbianelf.backup
popd
popenv

# task [128/130] /fini/sources_package
pushenv
pushenvvar CC_FOR_BUILD i686-pc-linux-gnu-gcc
mkdir -p /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf
cp /scratch/julian/2010q1-release-symbian-lite/obj/gnu-2010q1-190-arm-none-symbianelf.txt /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf
cp /scratch/julian/2010q1-release-symbian-lite/logs/arm-2010q1-190-arm-none-symbianelf.sh /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf/arm-2010q1-190-arm-none-symbianelf
pushd /scratch/julian/2010q1-release-symbian-lite/obj/pkg-2010q1-190-arm-none-symbianelf
tar cjf /scratch/julian/2010q1-release-symbian-lite/pkg/arm-2010q1-190-arm-none-symbianelf.src.tar.bz2 --owner=0 --group=0 arm-2010q1-190-arm-none-symbianelf
popd
/scratch/julian/2010q1-release-symbian-lite/src/scripts-trunk/gnu-test -i /scratch/julian/2010q1-release-symbian-lite/install -l /scratch/julian/2010q1-release-symbian-lite/logs -o /scratch/julian/2010q1-release-symbian-lite/obj -p /scratch/julian/2010q1-release-symbian-lite/pkg -s /scratch/julian/2010q1-release-symbian-lite/src -T /scratch/julian/2010q1-release-symbian-lite/testlogs -T /scratch/julian/2010q1-release-symbian-lite/obj/testlogs-2010q1-190-arm-none-symbianelf sgxx/2010q1/arm-none-symbianelf-lite.cfg
copy_dir /scratch/julian/2010q1-release-symbian-lite/obj/testlogs-2010q1-190-arm-none-symbianelf /scratch/julian/2010q1-release-symbian-lite/testlogs
/scratch/julian/2010q1-release-symbian-lite/src/scripts-trunk/gnu-test-package -i /scratch/julian/2010q1-release-symbian-lite/install -l /scratch/julian/2010q1-release-symbian-lite/logs -o /scratch/julian/2010q1-release-symbian-lite/obj -p /scratch/julian/2010q1-release-symbian-lite/pkg -s /scratch/julian/2010q1-release-symbian-lite/src -T /scratch/julian/2010q1-release-symbian-lite/testlogs -T /scratch/julian/2010q1-release-symbian-lite/obj/testlogs-2010q1-190-arm-none-symbianelf sgxx/2010q1/arm-none-symbianelf-lite.cfg
